@@ -76,6 +76,9 @@ private:
   size_t               themeIndex;
 
 private:
+  // Base class
+  void UpdateDimensions();
+
   // Drawing
   size_t GetBoxSize() const;
   Lum::Images::Image* GetImage(Image image) const;
@@ -99,7 +102,6 @@ public:
 
   void CalcSize();
 
-  void Layout();
   void Draw(int x, int y, size_t w, size_t h);
 
   bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
