@@ -26,6 +26,8 @@
 #include <Lum/Base/String.h>
 #include <Lum/Base/Util.h>
 
+#include <Lum/Def/Menu.h>
+
 #include <Lum/Dlg/About.h>
 #include <Lum/Dlg/ActionDialog.h>
 #include <Lum/Dlg/Help.h>
@@ -43,7 +45,6 @@
 #include <Lum/Dialog.h>
 #include <Lum/Grid.h>
 #include <Lum/Label.h>
-#include <Lum/Menu.h>
 #include <Lum/Slider.h>
 #include <Lum/String.h>
 #include <Lum/Table.h>
@@ -565,22 +566,25 @@ public:
 
     SetMain(vPanel);
 
-    Lum::MenuDesc *menu=new Lum::MenuDesc();
+    Lum::Def::Menu *menu=Lum::Def::Menu::Create();
 
     menu
-      ->AddMenuItemSub(_ld(menuProject))
-        ->AddMenuItemAction(L"_New Game",Lum::OS::qualifierControl,L"n",newGameAction)
-        ->AddSeparator()
-        ->AddMenuItemAction(L"_Hiscore...",hiscoreAction)
-        ->AddSeparator()
-        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
-    menu
-      ->AddMenuItemSub(L"Settings")
-        ->AddMenuItemAction(L"_Settings...",settingsAction);
-    menu
-      ->AddMenuItemSub(_ld(menuHelp))
-        ->AddMenuItemAction(_ld(menuHelpHelp),helpAction)
-        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+      ->GroupProject()
+        ->Action(Lum::Def::Action(Lum::Def::Desc(L"_New Game")
+                                  .SetShortcut(Lum::OS::qualifierControl,L"n"),
+                                  newGameAction))
+        ->Separator()
+        ->Action(Lum::Def::Action(Lum::Def::Desc(L"_Hiscore..."),hiscoreAction))
+        ->Separator()
+        ->ActionQuit(GetClosedAction())
+      ->End()
+      ->GroupEdit()
+        ->ActionSettings(settingsAction)
+      ->End()
+      ->GroupHelp()
+        ->ActionHelp(helpAction)
+        ->ActionAbout(aboutAction)
+      ->End();
 
     SetMenu(menu);
 
